import { url } from "../../App";
import { useHistory, useParams } from "react-router-dom";
import { useEffect, useState } from "react";

import './style.scss'

import {
    Avatar,
    IconButton,
    Typography,
    Box,
    Divider,
} from '@mui/material'
import {
    FavoriteBorderRounded,
} from '@mui/icons-material/'
import Grid from '@mui/material/Unstable_Grid2';


import { actionFindCommentsAnswerTo } from "../redux/action";
import { actionFullFindCommentsPostOne } from "../redux/thunks";
import { connect, useDispatch } from "react-redux";


function CommentCard({ data }) {
    // console.log('data: ', data)

    const history = useHistory()
    const dispatch = useDispatch()

    let answerToCommentData
    // скрываем/открываем вложенные комментарии
    const [openComments, setOpenComments] = useState('Посмотреть ответы')
    // скрываем/открываем блок с ответами на комментарии
    const [toggleAnswerToBlock, setToggleAnswerToBlock] = useState(false)

    // функция скрытия/открытия ответов на комменты
    async function changeText(id) {
        setToggleAnswerToBlock(!toggleAnswerToBlock)

        await dispatch(actionFindCommentsAnswerTo(id))

        return (openComments === 'Посмотреть ответы'
            ? setOpenComments('Скрыть ответы')
            : setOpenComments('Посмотреть ответы')
        )
    }






    // дата поста
    const dateofPost = new Date(+data?.createdAt)
    const months = ['января', 'февраля', 'марта', 'апреля', 'мая', 'июня', 'июля', 'августа', 'сентября', 'октября', 'ноября', 'декабря']
    const dateofPostParse = `${dateofPost.getDate() < 10 ? '0' + dateofPost.getDate() : dateofPost.getDate()} 
    ${months[dateofPost.getMonth()]} 
    ${dateofPost.getFullYear()}
    ${dateofPost.getHours()}:${dateofPost.getMinutes() < 10 ? '0' + dateofPost.getMinutes() : dateofPost.getMinutes()}`


    function toAccount(id) {
        history.push(`/user/${id}`)
    }


    return (
        <Grid
            container
            spacing={2}
            sx={{
                marginBottom: 1
            }}
        >
            <Grid
                item
                xs={2}
                sx={{
                    flex: '0 0 45px'
                }}
            >
                <Avatar
                    alt={data?.owner?.login}
                    src={(url + data?.owner?.avatar?.url)}
                    sx={{
                        width: 40,
                        height: 40
                    }}
                />
            </Grid>

            <Grid
                item
                xs={10}
                container
            >
                <Grid
                    xs={11}
                    sx={{
                        paddingBottom: 0
                    }}
                >
                    <Typography
                        variant="subtitle2"
                        color="text.secondary"
                        sx={{
                            cursor: 'pointer'
                        }}
                        onClick={() => toAccount(data?.owner?._id)}
                    >
                        {data?.owner?.login}
                    </Typography>

                    <Typography
                        variant="subtitle2"
                        color="text.secondary"
                    >
                        {data?.title}
                    </Typography>

                    <Typography
                        variant="body2"
                        color="text.secondary"
                    >
                        {data?.text}
                    </Typography>
                </Grid>

                <Grid
                    xs={1}
                    sx={{
                        paddingBottom: 0
                    }}
                >
                    <IconButton
                        onClick={() => (console.log('click like comment'))}
                    >
                        <FavoriteBorderRounded
                            fontSize='small'
                        />
                    </IconButton>
                </Grid>

                <Grid
                    xs={6}
                    sx={{
                        padding: 0,
                        paddingLeft: 1

                    }}
                >
                    <Typography
                        variant="caption"
                        color="text.disabled"
                        align='left'
                    >
                        {dateofPostParse}
                    </Typography>
                </Grid>

                <Grid
                    xs={3.5}
                    sx={{
                        padding: 0
                    }}
                >
                    <Typography
                        variant="caption"
                        color="text.disabled"
                        align='left'
                    >
                        Нравится: {data?.likesCount || '0'}
                    </Typography>
                </Grid>

                <Grid
                    xs={2.5}
                    sx={{
                        padding: 0,
                        paddingRight: 1
                    }}
                >
                    <Typography
                        variant="caption"
                        color="text.disabled"
                        align='left'
                        sx={{
                            cursor: 'pointer'
                        }}
                        onClick={() => (console.log('click answer on comment'))}
                    >
                        Ответить
                    </Typography>
                </Grid>

                <Grid
                    xs={12}
                    sx={{
                        padding: '0 8px'
                    }}
                >
                    {(data?.answers.length !== 0) &&
                        <Divider>
                            <Typography
                                variant="caption"
                                color="text.disabled"
                                sx={{
                                    cursor: 'pointer'
                                }}
                                onClick={() => changeText(data?._id)}
                            >
                                {openComments}
                            </Typography>
                        </Divider>}
                </Grid>

                {toggleAnswerToBlock &&
                    <Grid xs={12}
                        sx={{
                            padding: '0 8px'
                        }}>
                        <div sx={{ backgroundColor: 'red' }}>тут будут новые комментарии/ а если их будет много, то они будут в одну строку или как то так</div>
                        <CommentCard data={answerToCommentData} />
                    </Grid>}
            </Grid>
        </Grid >
    )
}

export default CommentCard